<?php

include_once(dirname(__FILE__).'/Database.php');
include_once(dirname(__FILE__).'/system.php');
include_once(dirname(__FILE__).'/Update.php');
include_once(dirname(__FILE__).'/rss.php');
include_once(dirname(__FILE__).'/user.php');
include_once(dirname(__FILE__).'/Page.php');
include_once(dirname(__FILE__).'/error.php');
if(file_exists(dirname(__FILE__).'/config.php')) 
  include_once(dirname(__FILE__).'/config.php');
include_once(dirname(__FILE__).'/Version.php');

GlobalInit();

function GlobalInit()
{
  global $System, $ScriptStartTime, $TranslationTree, $User, $StopAfterUpdateManager,
	$UpdateManager, $Config, $DatabaseRevision;

  $ScriptStartTime = GetMicrotime();

  if(isset($_SERVER['REMOTE_ADDR'])) session_start();

  if(!isset($Config)) die('Systém není nainstalován. Pokračujte v instalaci <a href="admin/install.php">zde</a>.');
  date_default_timezone_set($Config['Web']['Timezone']);
  
  $System = new System();
  $System->Init();

  // Check database persistence structure
  $UpdateManager = new UpdateManager();
  $UpdateManager->Database = $System->Database;
  $UpdateManager->Revision = $DatabaseRevision;
  if(!$UpdateManager->IsInstalled()) die('Systém vyžaduje instalaci databáze.');
  if(!$UpdateManager->IsUpToDate()) die('Systém vyžaduje aktualizaci databáze.');

  // SQL injection hack protection
  foreach($_POST as $Index => $Item)
  {
  	if(is_array($_POST[$Index]))
  		foreach($_POST[$Index] as $Index2 => $Item2) $_POST[$Index][$Index2] = addslashes($Item2);
  	else $_POST[$Index] = addslashes($_POST[$Index]);
  }
  foreach($_GET as $Index => $Item) $_GET[$Index] = addslashes($_GET[$Index]);
  
  $User = new User($System);
  
  set_error_handler('CustomErrorHandler');

  // TODO: Global initialized variable should be removed
  $TranslationTree = GetTranslationTree();

  LogReferrer();
}

$RSSChannels = array(
  array('Title' => 'Změny systému', 'Channel' => 'news'),
  array('Title' => 'Poslední překlady', 'Channel' => 'translation'),
  array('Title' => 'Kecátko', 'Channel' => 'shoutbox'),
);

function GetMicrotime()
{
  list($Usec, $Sec) = explode(' ', microtime());
  return ((float)$Usec + (float)$Sec);
}

$UnitNames = array('B', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB');
 
function HumanSize($Value)
{
  global $UnitNames;

  $UnitIndex = 0;
  while($Value > 1024)
  {
    $Value = round($Value / 1024, 3);
    $UnitIndex++;
  }
  return($Value.' '.$UnitNames[$UnitIndex]);
}

function GetQueryStringArray($QueryString)
{
  $Result = array();
  $Parts = explode('&', $QueryString);
  foreach($Parts as $Part)
  {
    if($Part != '')
    {
      if(!strpos($Part, '=')) $Part .= '=';
      $Item = explode('=', $Part);
      $Result[$Item[0]] = $Item[1];
    }
  }
  return($Result);
}

function SetQueryStringArray($QueryStringArray)
{
  $Parts = array();
  foreach($QueryStringArray as $Index => $Item)
  {
    $Parts[] = $Index.'='.$Item;
  }
  return(implode('&', $Parts));
}

// Log types
define('LOG_TYPE_TRANSLATION', 1);
define('LOG_TYPE_DOWNLOAD', 2);
define('LOG_TYPE_USER', 3);
define('LOG_TYPE_MODERATOR', 4);
define('LOG_TYPE_ERROR', 10);
define('LOG_TYPE_IMPORT', 11);
define('LOG_TYPE_EXPORT', 12);
define('LOG_TYPE_CZWOW', 13);
define('LOG_TYPE_ADMINISTRATION', 14);


function utf2ascii($text)
{
  $return = Str_Replace(
    Array("á","č","ď","é","ě","í","ľ","ň","ó","ř","š","ť","ú","ů","ý","ž","Á","Č","Ď","É","Ě","Í","Ľ","Ň","Ó","Ř","Š","Ť","Ú","Ů","Ý","Ž") ,
    Array("a","c","d","e","e","i","l","n","o","r","s","t","u","u","y","z","A","C","D","E","E","I","L","N","O","R","S","T","U","U","Y","Z") ,
    $text);
  //$return = Str_Replace(Array(" ", "_"), "-", $return); //nahradí mezery a podtržítka pomlčkami
  //$return = Str_Replace(Array("(",")",".","!",",","\"","'"), "", $return); //odstraní ().!,"'
  //$return = StrToLower($return); // velká písmena nahradí malými.
  return($return);
}

function getmonthyears($Days) 
{
  $month = floor($Days / 30);
  $year = floor($month / 12);
  $Days = floor($Days - $month * 30);
  $month = $month - $year * 12; 
  return($year.'r '.$month.'m '.$Days.'d');
}

function GetPageList($TotalCount)
{
  global $System;
    
  $QueryItems = GetQueryStringArray($_SERVER['QUERY_STRING']);
  
  $ItemPerPage = $System->Config['Web']['ItemsPerPage'];
  $Around = round($System->Config['Web']['VisiblePagingItems'] / 2);
  $Result = '';
  $PageCount = floor($TotalCount / $ItemPerPage) + 1;
  
  if(!array_key_exists('Page', $_SESSION)) $_SESSION['Page'] = 0;
  if(array_key_exists('page', $_GET)) $_SESSION['Page'] = $_GET['page'] * 1;
  if($_SESSION['Page'] < 0) $_SESSION['Page'] = 0;
  if($_SESSION['Page'] >= $PageCount) $_SESSION['Page'] = $PageCount - 1;
  $CurrentPage = $_SESSION['Page'];
  
        
  $Result .= 'Počet položek: <strong>'.$TotalCount.'</strong> &nbsp; Stránky: ';

  $Result = '';
  if($PageCount > 1)
  {
    if($CurrentPage > 0) 
    {
      $QueryItems['page'] = 0;      
      $Result.= '<a href="?'.SetQueryStringArray($QueryItems).'">&lt;&lt;</a> ';
      $QueryItems['page'] = ($CurrentPage - 1);
      $Result.= '<a href="?'.SetQueryStringArray($QueryItems).'">&lt;</a> ';
    }
    $PagesMax = $PageCount - 1;
    $PagesMin = 0;
    if($PagesMax > ($CurrentPage + $Around)) $PagesMax = $CurrentPage + $Around;
    if($PagesMin < ($CurrentPage - $Around))
    {
      $Result.= ' ... ';
      $PagesMin = $CurrentPage - $Around;
    }
    for($i = $PagesMin; $i <= $PagesMax; $i++)
    {
      if($i == $CurrentPage) $Result.= '<strong>'.($i + 1).'</strong> ';
      else {
       $QueryItems['page'] = $i;
       $Result .= '<a href="?'.SetQueryStringArray($QueryItems).'">'.($i + 1).'</a> ';
      }
    } 
    if($PagesMax < ($PageCount - 1)) $Result .= ' ... ';
    if($CurrentPage < ($PageCount - 1)) 
    {
      $QueryItems['page'] = ($CurrentPage + 1);
      $Result.= '<a href="?'.SetQueryStringArray($QueryItems).'">&gt;</a> ';
      $QueryItems['page'] = ($PageCount - 1);
      $Result.= '<a href="?'.SetQueryStringArray($QueryItems).'">&gt;&gt;</a>';
    }
  }
  $Result = '<div style="text-align: center">'.$Result.'</div>';
  return(array('SQLLimit' => ' LIMIT '.$CurrentPage * $ItemPerPage.', '.$ItemPerPage, 
    'Page' => $CurrentPage,
    'Output' => $Result,
  ));
}

$OrderDirSQL = array('ASC', 'DESC');
$OrderArrowImage = array('sort_asc.png', 'sort_desc.png');

function GetOrderTableHeader($Columns, $DefaultColumn, $DefaultOrder = 0)
{
  global $OrderDirSQL, $OrderArrowImage, $Config, $System;
  
  if(array_key_exists('OrderCol', $_GET)) $_SESSION['OrderCol'] = $_GET['OrderCol'];
  if(array_key_exists('OrderDir', $_GET)) $_SESSION['OrderDir'] = $_GET['OrderDir'];
  if(!array_key_exists('OrderCol', $_SESSION)) $_SESSION['OrderCol'] = $DefaultColumn;
  if(!array_key_exists('OrderDir', $_SESSION)) $_SESSION['OrderDir'] = $DefaultOrder;
  
  // Check OrderCol
  $Found = false;
  foreach($Columns as $Column)
  {
    if($Column['Name'] == $_SESSION['OrderCol'])
    {
      $Found = true;    
      break;
    }
  }
  if($Found == false)
  {
    $_SESSION['OrderCol'] = $DefaultColumn;
    $_SESSION['OrderDir'] = $DefaultOrder;
  }
  // Check OrderDir
  if(($_SESSION['OrderDir'] != 0) and ($_SESSION['OrderDir'] != 1)) $_SESSION['OrderDir'] = 0;
  
  $Result = '';
  $QueryItems = GetQueryStringArray($_SERVER['QUERY_STRING']);
  foreach($Columns as $Index => $Column)
  {
    $QueryItems['OrderCol'] = $Column['Name'];
    $QueryItems['OrderDir'] = 1 - $_SESSION['OrderDir'];
    if($Column['Name'] == $_SESSION['OrderCol']) $ArrowImage = '<img  style="vertical-align: middle; border: 0px;" src="'.$System->Link('/images/'.$OrderArrowImage[$_SESSION['OrderDir']]).'" alt="order arrow">';
      else $ArrowImage = '';
    if($Column['Name'] == '') $Result .= '<th>'.$Column['Title'].'</th>';
      else $Result .= '<th><a href="?'.SetQueryStringArray($QueryItems).'">'.$Column['Title'].$ArrowImage.'</a></th>';
  }
  return(array(
    'SQL' => ' ORDER BY `'.$_SESSION['OrderCol'].'` '.$OrderDirSQL[$_SESSION['OrderDir']],
    'Output' => '<tr>'.$Result.'</tr>',
    'Column' => $_SESSION['OrderCol'],
    'Direction' => $_SESSION['OrderDir'],
  ));
}

function FormatOutput($s)
{
  $out = '';
  $nn = 0;
  $n = 0;
  while($s != '')
  {
    $start = strpos($s, '<');
    $end = strpos($s, '>');
    if($start != 0) 
    {
      $end = $start - 1;
      $start = 0;
    }
    $line = trim(substr($s, $start, $end + 1));
    if(strlen($line) > 0) 
    if($line[0] == '<')
    {
      if($s[$start + 1] == '/') 
      {
        $n = $n - 2;
        $nn = $n;
      } else 
      {
        if(strpos($line, ' ')) $cmd = substr($line, 1, strpos($line, ' ') - 1);
        else $cmd = substr($line, 1, strlen($line) - 2);
        //echo('['.$cmd.']');
        if(strpos($s, '</'.$cmd.'>')) $n = $n + 2;
      }   
    }// else $line = '['.$line.']';
    //if($line != '') echo(htmlspecialchars(str_repeat(' ',$nn).$line."\n"));
    if($line != '') $out .= (str_repeat(' ', $nn).$line."\n");
    $s = substr($s, $end + 1, strlen($s));
    $nn = $n;
  }
  return($out);
}

function WriteLanguages($Selected)
{
  global $System;
  
  $Output = '<select name="Language">';
  $DbResult = $System->Database->select('Language', '`Id`, `Name`', '`Enabled` = 1');
  while($Language = $DbResult->fetch_assoc())
  {
    $Output .= '<option value="'.$Language['Id'].'"'; 
    if($Selected == $Language['Id']) 
      $Output .= ' selected="selected"';
    $Output .= '>'.$Language['Name'].'</option>';
  }    
  $Output .= '</select>';
  return($Output);    
}

function ClientVersionSelection($Selected)
{
  global $System;
  
  $Output = '<select name="ClientVersion">';
  $DbResult = $System->Database->select('ClientVersion', '`Id`, `Version`', '`Imported` = 1');
  $Output .= '<option value=""'; 
  if($Selected == '') 
    $Output .= ' selected="selected"';
  $Output .= '>Žádná</option>';
  while($ClientVersion = $DbResult->fetch_assoc())
  {
    $Output .= '<option value="'.$ClientVersion['Id'].'"'; 
    if($Selected == $ClientVersion['Id']) 
      $Output .= ' selected="selected"';
    $Output .= '>'.$ClientVersion['Version'].'</option>';
  }    
  $Output .= '</select>';
  return($Output);    
}

function GetLanguageList()
{ 
  global $System;
  
  $Result = array();
  $DbResult = $System->Database->query('SELECT * FROM `Language` WHERE `Enabled` = 1');
  while($DbRow = $DbResult->fetch_assoc())
    $Result[$DbRow['Id']] = $DbRow;
  return($Result);
}

function GetTranslationTree()
{ 
  global $System;
  
  $Result = array();
  $DbResult = $System->Database->query('SELECT *, UNIX_TIMESTAMP(`LastImport`) AS `LastImportTime` FROM `Group` ORDER BY `Name`');
  while($DbRow = $DbResult->fetch_assoc())
  {
    $DbRow['Items'] = array();
    $Result[$DbRow['Id']] = $DbRow;
  }
  $DbResult = $System->Database->query('SELECT * FROM `GroupItem` ORDER BY `Group`, `Sequence`');
  while($DbRow = $DbResult->fetch_assoc())
  {
    $Result[$DbRow['Group']]['Items'][] = $DbRow;
  }
  return($Result);
}

$Moderators = array('Překladatel', 'Moderátor', 'Administrátor');

function WriteLog($Text, $Type)
{
  global $System, $User;
 
  if(!isset($_SERVER['REMOTE_ADDR'])) $IP = 'Konzole';
    else $IP = addslashes($_SERVER['REMOTE_ADDR']);

  if(!is_null($User->Id)) $UserId = $User->Id;
    else $UserId = 'NULL';
  $Query = 'INSERT INTO `Log` ( `User` , `Type` , `Text` , `Date` , `IP` )
   VALUES ('.$UserId.', '.$Type.', "'.addslashes($Text).'", NOW(), "'.$IP.'")';
  $System->Database->query($Query);
}

function HumanDate($SQLDateTime)
{
  $DateTimeParts = explode(' ', $SQLDateTime);
  if($DateTimeParts[0] != '0000-00-00')
  {
    $DateParts = explode('-', $DateTimeParts[0]);
    return(($DateParts[2] * 1).'.'.($DateParts[1] * 1).'.'.($DateParts[0] * 1));
  } else return('&nbsp;');
}

function FollowingTran($TextID, $Table, $GroupId, $Prev = false) 
{ 
  global $System, $Config;
  
  if($Prev)
    $sql = 'SELECT `ID` FROM `'.$Table.'` AS `item` WHERE '.
      '(`Language` = '.$Config['OriginalLanguage'].') AND NOT EXISTS(SELECT `entry` '.
      'FROM `'.$Table.'` AS `sub` WHERE (`sub`.`Language` <> '.$Config['OriginalLanguage'].') '.
      'AND (`sub`.`entry` = `item`.`entry`)) AND (`ID` < '.$TextID.') ORDER BY `ID` DESC LIMIT 1';
    else $sql = 'SELECT `ID` FROM `'.$Table.'` AS `item` WHERE '.
      '(`Language` = '.$Config['OriginalLanguage'].') AND NOT EXISTS(SELECT `entry` '.
      'FROM `'.$Table.'` AS `sub` WHERE (`sub`.`Language` <> '.$Config['OriginalLanguage'].') '.
      'AND (`sub`.`entry` = `item`.`entry`)) AND `ID` > '.$TextID.' ORDER BY `ID` LIMIT 1';
  
  $DbResult = $System->Database->query($sql);
  $Next = $DbResult->fetch_assoc();
  if($Next) 
  {
    if($Prev) $Output = '<a href="form.php?group='.$GroupId.'&amp;ID='.$Next['ID'].'">Předcházející '.$Next['ID'].'</a> ';
    else $Output = '<a href="form.php?group='.$GroupId.'&amp;ID='.$Next['ID'].'">Následující '.$Next['ID'].'</a> ';
      return('form.php?group='.$GroupId.'&amp;ID='.$Next['ID']);
  }
}

function GetBuildNumber($Version)
{
  global $System, $BuildNumbers;
  
  if(isset($BuildNumbers[$Version]) == false) 
  {
    $sql = 'SELECT `BuildNumber` FROM `ClientVersion` WHERE `Version` = "'.$Version.'"';
    $DbResult = $System->Database->query($sql);
    $DbRow = $DbResult->fetch_assoc();
    $BuildNumbers[$Version] = $DbRow['BuildNumber'];
  }
  return($BuildNumbers[$Version]);
}

function GetVersionWOW($BuildNumber)
{
  global $System, $VersionsWOW;
  
  if(isset($VersionsWOW[$BuildNumber]) == false) 
  {
    $sql = 'SELECT `Version` FROM `ClientVersion` WHERE `BuildNumber` = "'.$BuildNumber.'"';
    $DbResult = $System->Database->query($sql);
    $Version = $DbResult->fetch_assoc();
    $VersionsWOW[$BuildNumber] = $Version['Version'];
  }
  return($VersionsWOW[$BuildNumber]);
}

function LoadGroupIdParameter()
{
  global $TranslationTree;
  
  if(array_key_exists('group', $_GET)) $GroupId = $_GET['group'] * 1; 
    else $GroupId = 1;
  
  if(isset($TranslationTree[$GroupId]) == false) ErrorMessage('Překladová skupina dle zadaného Id neexistuje.');
  return($GroupId);
}

function LoadCommandLineParameters()
{
  if(!array_key_exists('REMOTE_ADDR', $_SERVER))
  {
    foreach($_SERVER['argv'] as $Parameter)
    {
      if(strpos($Parameter, '=') !== false)
      {
        $Index = substr($Parameter, 0, strpos($Parameter, '='));
        $Parameter = substr($Parameter, strpos($Parameter, '=') + 1);
        //echo($Index.'  ----  '.$Parameter);
        $_GET[$Index] = $Parameter;
      }
    } 
  }
}

function ShowTabs($Tabs)
{
  $QueryItems = GetQueryStringArray($_SERVER['QUERY_STRING']);
  
  if(array_key_exists('Tab', $_GET)) $_SESSION['Tab'] = $_GET['Tab'];
  if(!array_key_exists('Tab', $_SESSION)) $_SESSION['Tab'] = 0;
  if(($_SESSION['Tab'] < 0) or ($_SESSION['Tab'] > (count($Tabs) - 1))) $_SESSION['Tab'] = 0;
  $Output = '<div id="header">'.
    '<ul>';
  foreach($Tabs as $Index => $Tab)
  {
    $QueryItems['Tab'] = $Index;
    if($Index == $_SESSION['Tab']) $Selected = ' id="selected"'; 
      else $Selected = '';
    $Output .= '<li'.$Selected.'><a href="?'.SetQueryStringArray($QueryItems).'">'.$Tab.'</a></li>';
  }
  $Output .= '</ul></div>';
  return($Output);
}

function CheckBox($Name, $Checked = false, $Id = '', $Class = '', $Disabled = false)
{
  if($Id) $Id = ' id="'.$Id.'"'; else $Id = '';
  if($Class) $Class = ' class="'.$Class.'"'; else $Class = '';
  if($Checked) $Checked = ' checked="checked"'; else $Checked = '';
  if($Disabled) $Disabled = ' disabled="disabled"'; else $Disabled = '';
  return('<input type="checkbox" value="checked" name="'.$Name.'"'.$Checked.$Disabled.$Id.$Class.' />');
}

function RadioButton($Name, $Value, $Checked = false, $OnClick = '', $Disabled = false)
{
  if($Checked) $Checked = ' checked="checked"'; else $Checked = '';
  if($OnClick != '') $OnClick = ' onclick="'.$OnClick.'"'; else $OnClick = '';
  if($Disabled) $Disabled = ' disabled="disabled"'; else $Disabled = '';
  return('<input type="radio" name="'.$Name.'" value="'.$Value.'"'.$Checked.$Disabled.$OnClick.'/>');
}

function SelectOption($Name, $Text, $Selected = false)
{
  if($Selected) $Selected = ' selected="selected"'; else $Selected = '';
  return('<option value="'.$Name.'"'.$Selected.'>'.$Text.'</option>');
}

function DeleteDirectory($dirname) 
{
  if(is_dir($dirname))
  {
    $dir_handle = opendir($dirname);
    if(!$dir_handle) return(false);
    while($file = readdir($dir_handle)) 
    {
      if(($file != '.') and ($file != '..'))
      {
        if(!is_dir($dirname.'/'.$file)) unlink($dirname.'/'.$file);
          else DeleteDirectory($dirname.'/'.$file);    
      }
    }
    closedir($dir_handle);
    rmdir($dirname);
  }
  return(true);
}

function ErrorMessage($Text)
{
  ShowPage($Text);
  die();
}

function GetIDbyName($Table) 
{
  global $TranslationTree;
  
  foreach($TranslationTree as $TableID => $Value) 
  {
    if($Value['TablePrefix'] == $Table) return $TableID;
  }
}

function GetTranslatNames($Text,$mode,$TablesColumn) 
{
  global $System, $Config;
  
 /* $TablesID = array('gameobject' => 5,
  'creature' => 6,
  'item' => 4,
  'transports' => 'Name',
  'areatrigger_teleport' => 'Name',
  'areatrigger_tavern' => 'Name',); */
    $buff = array();
  
  foreach($TablesColumn as $Table => $Column) 
  {  
    $sql = 'SELECT `ID`,`'.$Column.'`, (SELECT `'.$Column.'` FROM `'.$Table.'` AS `T` WHERE '.
      '(`O`.`Entry` = `T`.`Entry`) AND (`Language` <> '.$Config['OriginalLanguage'].') LIMIT 1) AS `Tran` FROM `'.$Table.'` AS `O` WHERE ';
    $groupby = ' GROUP BY `'.$Column.'`';
  
    $ArrStr = explode(' ', $Text);
    $where = '(`Language` = '.$Config['OriginalLanguage'].') ';
    if ($mode == 1) $where .= ' AND EXISTS(SELECT 1 FROM `'.$Table.'` AS `Sub` WHERE (`Sub`.`Language` <> '.$Config['OriginalLanguage'].') AND (`Sub`.`Entry` = `O`.`Entry`))';
    if ($mode == 2) $where .= ' AND NOT EXISTS(SELECT 1 FROM `'.$Table.'` AS `Sub` WHERE (`Sub`.`Language` <> '.$Config['OriginalLanguage'].') AND (`Sub`.`Entry` = `O`.`Entry`))';
    $where .= ' AND ('; 
    
    $SqlOK = false;
    if (count($ArrStr) > 0) {
      for($i = 0; $i < count($ArrStr); $i++)
      {
        if (strpos($ArrStr[$i],"'s") > 0)
       $ArrStr[$i] = substr($ArrStr[$i],0,strlen($ArrStr[$i])-2);
        if (strpos($ArrStr[$i],',') > 0) $ArrStr[$i] = substr($ArrStr[$i],0,strlen($ArrStr[$i])-1);
        if (strpos($ArrStr[$i],'.') > 0) $ArrStr[$i] = substr($ArrStr[$i],0,strlen($ArrStr[$i])-1);
        if (strpos($ArrStr[$i],'!') > 0) $ArrStr[$i] = substr($ArrStr[$i],0,strlen($ArrStr[$i])-1);
        if (strpos($ArrStr[$i],'?') > 0) $ArrStr[$i] = substr($ArrStr[$i],0,strlen($ArrStr[$i])-1);

        if (strlen($ArrStr[$i]) > 4) {
          $where .= '(`O`.`'.$Column.'` LIKE "%'.addslashes($ArrStr[$i]).'%") OR ';
          $SqlOK = true;
      }
      }
      $where = substr($where, 0, strlen($where) - 4);
      $where .= ')';
      if ($SqlOK) {
        $DbResult = $System->Database->query($sql.$where.$groupby);
    //  echo ($sql.'|'.$where.'|'.$groupby);
        while($Line = $DbResult->fetch_assoc()) 
        {
          $buff[] = array($Line['ID'], GetIDbyName($Table), $Line[$Column], $Line['Tran']);
        }
    }
    }
  }
    return $buff;
}

function ProgressBar($Width, $Percent, $Text = '')
{
  $Pixels = $Width * ($Percent / 100);
  if($Pixels > $Width) $Pixels = $Width;
  if($Text == '') $Text = $Percent;
  
  return('<div class="progressbar" style="width: '.$Width.'px">'.
    '<div class="bar" style="width: '.$Pixels.'px;"></div>'.  
    '<div class="text" style="width: '.$Width.'px">'.$Text.'</div>'.  
    '</div>');
}

function GetLevelMinMax($XP)
{
  $IndexLevel = 100;
  
  if($XP > 0) $Level = floor(sqrt($XP / $IndexLevel));
    else $Level = 0;
  $MinXP = $Level * $Level * $IndexLevel;
  $MaxXP = ($Level + 1) * ($Level + 1) * $IndexLevel;
  $MaxXP = $MaxXP - $MinXP;
  $XP = $XP - $MinXP;
  return(array('Level' => $Level, 'XP' => $XP, 'MaxXP' => $MaxXP));
}

function GetParameter($Name, $Default = '', $Numeric = false, $Session = false)
{
  $Result = $Default;
  if(array_key_exists($Name, $_GET)) $Result = $_GET[$Name];
  else if(array_key_exists($Name, $_POST)) $Result = $_POST[$Name];
  else if($Session and array_key_exists($Name, $_SESSION)) $Result = $_SESSION[$Name];
  if($Numeric and !is_numeric($Result)) $Result = $Default;
  if($Session) $_SESSION[$Name] = $Result;
  return($Result);
}

function LogReferrer()
{
  global $System;

  if(array_key_exists('HTTP_REFERER', $_SERVER)) 
  {
    $Referrer = addslashes($_SERVER['HTTP_REFERER']);
    $HostName = substr($Referrer, strpos($Referrer, '/') + 2);
    $HostName = substr($HostName, 0, strpos($HostName, '/'));
    if($HostName != $System->Config['Web']['Host'])
    {
      $DbResult = $System->Database->query('SELECT `Id` FROM `Referrer` WHERE `Web` = "'.$HostName.'"');
      if($DbResult->num_rows > 0)
      {
        $DbRow = $DbResult->fetch_assoc();
        $System->Database->query('UPDATE `Referrer` SET `Hits` = `Hits` + 1, `DateLast` = NOW(), `LastURL` = "'.addslashes($Referrer).'" WHERE `Id` = '.$DbRow['Id']);
      } else $System->Database->query('INSERT INTO `Referrer` (`Web`, `DateFirst`, `DateLast`, `LastURL`, `Hits`) VALUES ("'.$HostName.'", NOW(), NOW( ), "'.addslashes($Referrer).'", 1)');
    }
  }
}

function MakeActiveLinks($Content)
{
  $Content = htmlspecialchars($Content);
  $Content = str_replace("\n", ' <br/>', $Content);
  $Content = str_replace("\r", '', $Content);
  
  $Result = '';  
  $I = 0;
  while(strpos($Content, 'http://') !== false)
  {
    $I = strpos($Content, 'http://');
    $Result .= substr($Content, 0, $I);
    $Content = substr($Content, $I);
    $SpacePos = strpos($Content, ' ');
    if($SpacePos !== false) $URL = substr($Content, 0, strpos($Content, ' '));
      else $URL = substr($Content, 0);
    
    $Result .= '<a href="'.$URL.'">'.$URL.'</a>';
    $Content = substr($Content, strlen($URL));
  }
  $Result .= $Content;
  return($Result);
}

define('MESSAGE_WARNING', 0);
define('MESSAGE_CRITICAL', 1);
define('MESSAGE_INFORMATION', 2);

function ShowMessage($Text, $Type = MESSAGE_INFORMATION)
{
  global $System;
  
  $IconName = array(
	MESSAGE_INFORMATION => 'information', 
    MESSAGE_WARNING => 'warning', 
    MESSAGE_CRITICAL => 'critical'
  );
  $BackgroundColor = array(
  	MESSAGE_INFORMATION => '#e0e0ff', 
    MESSAGE_WARNING => '#ffffe0', 
  	MESSAGE_CRITICAL => '#ffe0e0'
  );
  
  return('<div class="message" style="background-color: '.$BackgroundColor[$Type].
  	';"><table><tr><td class="icon"><img src="'.
  	$System->Link('/images/message/'.$IconName[$Type].'.png').'" alt="'.
  	$IconName[$Type].'"><td>'.$Text.'</td></tr></table></div>');
}

function HandleLoginForm()
{
  global $User, $Message, $MessageType;
  
  if(array_key_exists('action', $_GET))
  {
    if($_GET['action'] == 'login')
    {
      if(array_key_exists('LoginUser', $_POST) and array_key_exists('LoginPass', $_POST))
      {
        $User->Login($_POST['LoginUser'], $_POST['LoginPass']);
        if($User->Role == LICENCE_ANONYMOUS)
        {
          $Message = 'Jméno nebo heslo bylo zadáno špatně.';
          $MessageType = MESSAGE_CRITICAL;
        } else
        {
          $Message = 'Přihlášení proběhlo úspěšně. Vítej <strong>'.$User->Name.'</strong>!';
          $MessageType = MESSAGE_INFORMATION;
        }
      } else
      {
        $Message = 'Nebylo zadáno jméno a heslo.';
        $MessageType = MESSAGE_CRITICAL;
      }
    } else
      if($_GET['action'] == 'logout')
      {
        if($User->Role != LICENCE_ANONYMOUS)
        {
          WriteLog('Odhlášení', LOG_TYPE_USER);
          $User->Logout();
          $Message = 'Byl jsi odhlášen.';
          $MessageType = MESSAGE_INFORMATION;
        }
      }
  }
}

?>
